Modules
Macros
- module_
end - The module_end! macro is used for defining the end function of a kernel module, this function should be used to check if the init function was successful.
- module_
init - The module_init! macro is used for defining the start function of a kernel module
- start_
module - The start_module! macro is used for starting a kernel module, make sure your module is linked to your project.